@@ -10,7 +10,7 @@ RHCOS_RELEASES_APP = 'https://releases-art-rhcos.svc.ci.openshift.org'
 
 parser = argparse.ArgumentParser()
 parser.add_argument("meta", action='store')
-parser.add_argument("arch", action='store', choices=['amd64'])
+parser.add_argument("arch", action='store', choices=['amd64', 's390x', 'ppc64le'])
 args = parser.parse_args()
 
 metadata_dir = os.path.join(os.path.dirname(sys.argv[0]), "../data/data")
@@ -25,16 +25,18 @@ newmeta = {}
 for k in ['images', 'buildid', 'oscontainer',
           'ostree-commit', 'ostree-version',
           'azure', 'gcp']:
-    newmeta[k] = meta[k]
-newmeta['amis'] = {
-    entry['name']: {
-        'hvm': entry['hvm'],
+    if meta.get(k):
+        newmeta[k] = meta[k]
+if meta.get(k):
+    newmeta['amis'] = {
+        entry['name']: {
+            'hvm': entry['hvm'],
+        }
+        for entry in meta['amis']
     }
-    for entry in meta['amis']
-}
 newmeta['baseURI'] = urllib.parse.urljoin(args.meta, '.')
 
-with open(os.path.join(metadata_dir, f"rhcos-{args.arch}.json"), 'w') as f:
+with open(os.path.join(metadata_dir, 'rhcos-{}.json'.format(args.arch)), 'w') as f:
     json.dump(newmeta, f, sort_keys=True, indent=4)
 
 # Continue to populate the legacy metadata file because there are still
